@@ -14,7 +14,7 @@ __author__ = (
     "Mark Harviston <mark.harviston@gmail.com>, "
     "Arve Knudsen <arve.knudsen@gmail.com>",
 )
-__version__ = "0.22.0"
+__version__ = "0.23.0"
 __url__ = "https://github.com/CabbageDevelopment/qasync"
 __license__ = "BSD"
 __all__ = ["QEventLoop", "QThreadExecutor", "asyncSlot", "asyncClose"]
@@ -772,7 +772,7 @@ def asyncClose(fn):
     return wrapper
 
 
-def asyncSlot(*args):
+def asyncSlot(*args, **kwargs):
     """Make a Qt async slot run on asyncio loop."""
 
     def _error_handler(task):
@@ -782,7 +782,7 @@ def asyncSlot(*args):
             sys.excepthook(*sys.exc_info())
 
     def outer_decorator(fn):
-        @Slot(*args)
+        @Slot(*args, **kwargs)
         @functools.wraps(fn)
         def wrapper(*args, **kwargs):
             task = asyncio.ensure_future(fn(*args, **kwargs))
